@@ -2,7 +2,7 @@
 #define MATRIX_SSCCROSSTAB_H
 
 #include "Mutils.h"
-#include "ldl.h"
+#include "R_ldl.h"
 
 SEXP sscCrosstab(SEXP flist, SEXP upper);
 extern void ssc_metis_order(int n, const int Tp [], const int Ti [],
